import asyncio

from fractal.client.client import main


def run():
    asyncio.run(main())


if __name__ == "__main__":
    run()
